@@ -204,6 +204,24 @@ mm_bearer_get_ip_timeout (MMBearer *self)
 
 /*****************************************************************************/
 
+/**
+ * mm_bearer_get_bearer_type:
+ * @self: A #MMBearer.
+ *
+ * Gets the type of bearer.
+ *
+ * Returns: a #MMBearerType.
+ */
+MMBearerType
+mm_bearer_get_bearer_type (MMBearer *self)
+{
+    g_return_val_if_fail (MM_IS_BEARER (self), MM_BEARER_TYPE_UNKNOWN);
+
+    return mm_gdbus_bearer_get_bearer_type (MM_GDBUS_BEARER (self));
+}
+
+/*****************************************************************************/
+
 static void
 ipv4_config_updated (MMBearer *self,
                      GParamSpec *pspec)
@@ -659,7 +677,7 @@ mm_bearer_peek_stats (MMBearer *self)
  *
  * Finishes an operation started with mm_bearer_connect().
  *
- * Returns: %TRUE if the operation succeded, %FALSE if @error is set.
+ * Returns: %TRUE if the operation succeeded, %FALSE if @error is set.
  */
 gboolean
 mm_bearer_connect_finish (MMBearer *self,
@@ -709,7 +727,7 @@ mm_bearer_connect (MMBearer *self,
  * The calling thread is blocked until a reply is received.
  * See mm_bearer_connect() for the asynchronous version of this method.
  *
- * Returns: %TRUE if the operation succeded, %FALSE if @error is set.
+ * Returns: %TRUE if the operation succeeded, %FALSE if @error is set.
  */
 gboolean
 mm_bearer_connect_sync (MMBearer *self,
@@ -756,7 +774,7 @@ mm_bearer_disconnect (MMBearer *self,
  *
  * Finishes an operation started with mm_bearer_disconnect().
  *
- * Returns: %TRUE if the operation succeded, %FALSE if @error is set.
+ * Returns: %TRUE if the operation succeeded, %FALSE if @error is set.
  */
 gboolean
 mm_bearer_disconnect_finish (MMBearer *self,
@@ -779,7 +797,7 @@ mm_bearer_disconnect_finish (MMBearer *self,
  * The calling thread is blocked until a reply is received.
  * See mm_bearer_disconnect() for the asynchronous version of this method.
  *
- * Returns: %TRUE if the operation succeded, %FALSE if @error is set.
+ * Returns: %TRUE if the operation succeeded, %FALSE if @error is set.
  */
 gboolean
 mm_bearer_disconnect_sync (MMBearer *self,
